==> zio-aws-cognitoidentity_2.13-5.17.153.1-sources.jar: zio/aws/cognitoidentity/model/GetIdentityPoolRolesResponse.scala <==
package zio.aws.cognitoidentity.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentity.model.primitives.{
  IdentityProviderName,
  ARNString,
  RoleType,
  IdentityPoolId
}
import scala.jdk.CollectionConverters._
final case class GetIdentityPoolRolesResponse(
    identityPoolId: Option[IdentityPoolId] = None,
    roles: Option[Map[RoleType, ARNString]] = None,
    roleMappings: Option[
      Map[IdentityProviderName, zio.aws.cognitoidentity.model.RoleMapping]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse = {
    import GetIdentityPoolRolesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
      .builder()
      .optionallyWith(
        identityPoolId.map(value =>
          IdentityPoolId.unwrap(value): java.lang.String
        )
      )(_.identityPoolId)
      .optionallyWith(
        roles.map(value =>
          value
            .map({ case (key, value) =>
              (RoleType.unwrap(key): java.lang.String) -> (ARNString
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.roles)
      .optionallyWith(
        roleMappings.map(value =>
          value
            .map({ case (key, value) =>
              (IdentityProviderName.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.roleMappings)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse.ReadOnly =
    zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse
      .wrap(buildAwsValue())
}
object GetIdentityPoolRolesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse =
      zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse(
        identityPoolId.map(value => value),
        roles.map(value => value),
        roleMappings.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        )
      )
    def identityPoolId: Option[IdentityPoolId]
    def roles: Option[Map[RoleType, ARNString]]
    def roleMappings: Option[Map[
      IdentityProviderName,
      zio.aws.cognitoidentity.model.RoleMapping.ReadOnly
    ]]
    def getIdentityPoolId: ZIO[Any, AwsError, IdentityPoolId] =
      AwsError.unwrapOptionField("identityPoolId", identityPoolId)
    def getRoles: ZIO[Any, AwsError, Map[RoleType, ARNString]] =
      AwsError.unwrapOptionField("roles", roles)
    def getRoleMappings: ZIO[Any, AwsError, Map[
      IdentityProviderName,
      zio.aws.cognitoidentity.model.RoleMapping.ReadOnly
    ]] = AwsError.unwrapOptionField("roleMappings", roleMappings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
  ) extends zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse.ReadOnly {
    override val identityPoolId: Option[IdentityPoolId] = scala
      .Option(impl.identityPoolId())
      .map(value =>
        zio.aws.cognitoidentity.model.primitives.IdentityPoolId(value)
      )
    override val roles: Option[Map[RoleType, ARNString]] = scala
      .Option(impl.roles())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.cognitoidentity.model.primitives.RoleType(
              key
            ) -> zio.aws.cognitoidentity.model.primitives.ARNString(value)
          })
          .toMap
      )
    override val roleMappings: Option[Map[
      IdentityProviderName,
      zio.aws.cognitoidentity.model.RoleMapping.ReadOnly
    ]] = scala
      .Option(impl.roleMappings())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.cognitoidentity.model.primitives.IdentityProviderName(
              key
            ) -> zio.aws.cognitoidentity.model.RoleMapping.wrap(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
  ): zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cognitoidentity_2.13-5.17.295.22-sources.jar: zio/aws/cognitoidentity/model/GetIdentityPoolRolesResponse.scala <==
package zio.aws.cognitoidentity.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.cognitoidentity.model.primitives.{
  IdentityProviderName,
  ARNString,
  RoleType,
  IdentityPoolId
}
import scala.jdk.CollectionConverters._
final case class GetIdentityPoolRolesResponse(
    identityPoolId: Optional[IdentityPoolId] = Optional.Absent,
    roles: Optional[Map[RoleType, ARNString]] = Optional.Absent,
    roleMappings: Optional[
      Map[IdentityProviderName, zio.aws.cognitoidentity.model.RoleMapping]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse = {
    import GetIdentityPoolRolesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
      .builder()
      .optionallyWith(
        identityPoolId.map(value =>
          IdentityPoolId.unwrap(value): java.lang.String
        )
      )(_.identityPoolId)
      .optionallyWith(
        roles.map(value =>
          value
            .map({ case (key, value) =>
              (RoleType.unwrap(key): java.lang.String) -> (ARNString
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.roles)
      .optionallyWith(
        roleMappings.map(value =>
          value
            .map({ case (key, value) =>
              (IdentityProviderName.unwrap(key): java.lang.String) -> value
                .buildAwsValue()
            })
            .asJava
        )
      )(_.roleMappings)
      .build()
  }
  def asReadOnly
      : zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse.ReadOnly =
    zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse
      .wrap(buildAwsValue())
}
object GetIdentityPoolRolesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse =
      zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse(
        identityPoolId.map(value => value),
        roles.map(value => value),
        roleMappings.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        )
      )
    def identityPoolId: Optional[IdentityPoolId]
    def roles: Optional[Map[RoleType, ARNString]]
    def roleMappings: Optional[Map[
      IdentityProviderName,
      zio.aws.cognitoidentity.model.RoleMapping.ReadOnly
    ]]
    def getIdentityPoolId: ZIO[Any, AwsError, IdentityPoolId] =
      AwsError.unwrapOptionField("identityPoolId", identityPoolId)
    def getRoles: ZIO[Any, AwsError, Map[RoleType, ARNString]] =
      AwsError.unwrapOptionField("roles", roles)
    def getRoleMappings: ZIO[Any, AwsError, Map[
      IdentityProviderName,
      zio.aws.cognitoidentity.model.RoleMapping.ReadOnly
    ]] = AwsError.unwrapOptionField("roleMappings", roleMappings)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
  ) extends zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse.ReadOnly {
    override val identityPoolId: Optional[IdentityPoolId] =
      zio.aws.core.internal
        .optionalFromNullable(impl.identityPoolId())
        .map(value =>
          zio.aws.cognitoidentity.model.primitives.IdentityPoolId(value)
        )
    override val roles: Optional[Map[RoleType, ARNString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.roles())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.cognitoidentity.model.primitives.RoleType(
                key
              ) -> zio.aws.cognitoidentity.model.primitives.ARNString(value)
            })
            .toMap
        )
    override val roleMappings: Optional[Map[
      IdentityProviderName,
      zio.aws.cognitoidentity.model.RoleMapping.ReadOnly
    ]] = zio.aws.core.internal
      .optionalFromNullable(impl.roleMappings())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.cognitoidentity.model.primitives.IdentityProviderName(
              key
            ) -> zio.aws.cognitoidentity.model.RoleMapping.wrap(value)
          })
          .toMap
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdentityPoolRolesResponse
  ): zio.aws.cognitoidentity.model.GetIdentityPoolRolesResponse.ReadOnly =
    new Wrapper(impl)
}
